Exception: Bdb::DbError
Overview
Errors generated by methods under the Bdb hierarchy will be of this class unless Ruby itself raises the error.
Instance Method Summary collapse
- #code ⇒ Bdb error code integer
-
#initialize(message, code) ⇒ Object
constructor
An error can only be generated internally.
Constructor Details
#initialize(message, code) ⇒ Object
An error can only be generated internally
96 97 98 99 100 101 102 |
# File 'ext/bdb.c', line 96 VALUE err_initialize(VALUE obj, VALUE , VALUE code) { VALUE args[1]; args[0]=; rb_call_super(1,args); return rb_ivar_set(obj,fv_err_code,code); } |